@@ -1,21 +1,7 @@
-/***************************************************************************
-                               kwqtabledelegate.h
-                             -------------------
-
-    begin                : Wed Mar 1 19:17:30 PST 2006
-    copyright            : (C) 2006-2010 by Peter Hedlund
-    email                : peter.hedlund@kdemail.net
-
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2006-2010 Peter Hedlund <peter.hedlund@kdemail.net>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "kwqtabledelegate.h"
 
@@ -62,8 +48,8 @@ void KWQTableDelegate::commitAndCloseEditor()
 {
   QWidget *editor = qobject_cast<QWidget *>(sender());
 
-  emit commitData(editor);
-  emit closeEditor(editor, QAbstractItemDelegate::NoHint);
+  Q_EMIT commitData(editor);
+  Q_EMIT closeEditor(editor, QAbstractItemDelegate::NoHint);
 }
 
 void KWQTableDelegate::drawDecoration(QPainter* painter, const QStyleOptionViewItem& option, const QRect& rect, const QPixmap& pixmap) const
